@@ -47,6 +47,7 @@ void glp_init_bbm1(struct bbm1 *parm)
       parm->btrack = BB_BESTP;
       parm->tol_int = 1e-6;
       parm->tol_obj = 1e-7;
+      parm->meth = 1;
       parm->form = 3;
       parm->scale = 1;
       parm->dual = 0;
@@ -121,6 +122,7 @@ int glp_call_bbm1(LPI *lpi, struct bbm1 *parm)
       LPSOL *sol;
       struct bbm1 _parm;
       struct rsm1_cp rsm_cp;
+      struct spx2 spx_cp;
       struct bbm1_cp bbm_cp;
       int ret, bstat, status, i, j;
       /* if parameter block is not specified, create the dummy one */
@@ -146,6 +148,9 @@ int glp_call_bbm1(LPI *lpi, struct bbm1 *parm)
       if (!(0.0 < parm->tol_obj && parm->tol_obj < 1.0))
          fault("glp_call_bbm1: tol_obj = %g; invalid parameter",
             parm->tol_obj);
+      if (!(parm->meth == 0 || parm->meth == 1))
+         fault("glp_call_bbm1: meth = %d; invalid parameter",
+            parm->meth);
       if (!(0 <= parm->form && parm->form <= 4))
          fault("glp_call_bbm1: form = %d; invalid parameter",
             parm->form);
@@ -161,50 +166,90 @@ int glp_call_bbm1(LPI *lpi, struct bbm1 *parm)
       /* the problem should be of MIP class */
       if (glp_get_num_int(lpi) == 0)
          fault("glp_call_bbm1: problem has no integer variables");
-      /* extract LP problem data from the problem object */
-      lp = extract_prob(lpi);
-      /* create LP solution block */
-      sol = create_lpsol(lp->m, lp->n);
-      /* STAGE 1: FIND OPTIMAL SOLUTION OF THE RELAXED LP PROBLEM */
-      /* prepare control parameters */
-      rsm_cp.what = 2; /* optimal solution is required */
-      rsm_cp.form = parm->form;
-      rsm_cp.scale = parm->scale;
-      rsm_cp.dual = parm->dual;
-      rsm_cp.steep = parm->steep;
-      rsm_cp.relax = parm->relax;
-      rsm_cp.tol_bnd = parm->tol_bnd;
-      rsm_cp.tol_dj = 0.30 * parm->tol_dj;
-      rsm_cp.tol_piv = parm->tol_piv;
-      rsm_cp.iter_max = 0;
-      rsm_cp.round = parm->round;
-      /* solve LP problem using the revised simplex method */
-      ret = rsm1_driver(lp, sol, &rsm_cp);
-      /* store obtained LP solution back to the problem object */
-      switch (sol->status)
-      {  case '?':
-            bstat = '?', status = GLP_UNDEF; break;
-         case 'O':
-            bstat = 'O', status = GLP_OPT; break;
-         case 'F':
-            bstat = 'P', status = GLP_FEAS; break;
-         case 'I':
-            bstat = 'N', status = GLP_INFEAS; break;
-         case 'N':
-            bstat = 'N', status = GLP_NOFEAS; break;
-         case 'U':
-            bstat = 'P', status = GLP_UNBND; break;
-         default:
-            insist(sol->status != sol->status);
+      /* STAGE 1: FIND AN OPTIMAL SOLUTION OF THE LP RELAXATION */
+      if (parm->meth == 0)
+      {  /* extract LP problem data from the problem object */
+         lp = extract_prob(lpi);
+         /* create LP solution block */
+         sol = create_lpsol(lp->m, lp->n);
+         /* prepare control parameters */
+         rsm_cp.what = 2; /* optimal solution is required */
+         rsm_cp.form = parm->form;
+         rsm_cp.scale = parm->scale;
+         rsm_cp.dual = parm->dual;
+         rsm_cp.steep = parm->steep;
+         rsm_cp.relax = parm->relax;
+         rsm_cp.tol_bnd = parm->tol_bnd;
+         rsm_cp.tol_dj = 0.30 * parm->tol_dj;
+         rsm_cp.tol_piv = parm->tol_piv;
+         rsm_cp.iter_max = 0;
+         rsm_cp.round = parm->round;
+         /* solve LP problem using the revised simplex method */
+         ret = rsm1_driver(lp, sol, &rsm_cp);
+         /* store obtained LP solution back to the problem object */
+         switch (sol->status)
+         {  case '?':
+               bstat = '?', status = GLP_UNDEF; break;
+            case 'O':
+               bstat = 'O', status = GLP_OPT; break;
+            case 'F':
+               bstat = 'P', status = GLP_FEAS; break;
+            case 'I':
+               bstat = 'N', status = GLP_INFEAS; break;
+            case 'N':
+               bstat = 'N', status = GLP_NOFEAS; break;
+            case 'U':
+               bstat = 'P', status = GLP_UNBND; break;
+            default:
+               insist(sol->status != sol->status);
+         }
+         glp_put_soln_info(lpi, bstat, status, sol->objval);
+         for (i = 1; i <= sol->m; i++)
+            glp_put_row_soln(lpi, i, sol->tagx[i], sol->valx[i],
+               sol->dx[i]);
+         for (j = 1; j <= sol->n; j++)
+            glp_put_col_soln(lpi, j, sol->tagx[sol->m+j],
+               sol->valx[sol->m+j], sol->dx[sol->m+j]);
       }
-      glp_put_soln_info(lpi, bstat, status, sol->objval);
-      for (i = 1; i <= sol->m; i++)
-         glp_put_row_soln(lpi, i, sol->tagx[i], sol->valx[i],
-            sol->dx[i]);
-      for (j = 1; j <= sol->n; j++)
-         glp_put_col_soln(lpi, j, sol->tagx[sol->m+j],
-            sol->valx[sol->m+j], sol->dx[sol->m+j]);
-      /* check if the LP relaxation has been found successfully */
+      else
+      {  /* prepare control parameters */
+         glp_init_spx2(&spx_cp);
+         spx_cp.scale = parm->scale;
+         spx_cp.tol_bnd = parm->tol_bnd;
+         spx_cp.tol_dj = 0.30 * parm->tol_dj;
+         spx_cp.tol_piv = parm->tol_piv;
+         spx_cp.round = parm->round;
+         /* solve LP problem using the primal simplex method */
+         ret = glp_simplex2(lpi, &spx_cp);
+         /* extract LP problem data from the problem object */
+         lp = extract_prob(lpi);
+         /* create LP solution block */
+         sol = create_lpsol(lp->m, lp->n);
+         sol->mipsol = 0;
+         switch (glp_get_status(lpi))
+         {  case GLP_UNDEF:
+               sol->status = '?'; break;
+            case GLP_OPT:
+               sol->status = 'O'; break;
+            case GLP_FEAS:
+               sol->status = 'F'; break;
+            case GLP_INFEAS:
+               sol->status = 'I'; break;
+            case GLP_NOFEAS:
+               sol->status = 'N'; break;
+            case GLP_UNBND:
+               sol->status = 'U'; break;
+            default: insist(lpi != lpi);
+         }
+         sol->objval = glp_get_obj_val(lpi);
+         for (i = 1; i <= sol->m; i++)
+            glp_get_row_soln(lpi, i, &sol->tagx[i], &sol->valx[i],
+               &sol->dx[i]);
+         for (j = 1; j <= sol->n; j++)
+            glp_get_col_soln(lpi, j, &sol->tagx[sol->m+j],
+               &sol->valx[sol->m+j], &sol->dx[sol->m+j]);
+      }
+      /* check if the LP relaxation has been solved successfully */
       if (!(ret == 0 && sol->status == 'O'))
       {  error("glp_call_bbm1: integer optimization not possible");
          goto done;
