@@ -281,8 +281,8 @@ int glp_write_mps(LPI *lp, char *fname, struct wmps *parm)
       if (marker % 2 == 1)
       {  /* close the last intorg/intend group (if not closed) */
          marker++;
-         fprintf(fp, "    M%07d  'MARKER'                 'INTEND'\n",
-            marker);
+         fprintf(fp, "    MARK%04d  'MARKER'                 'INTEND'\n"
+            , marker);
       }
       ufree(rn);
       ufree(aj);
