@@ -23,11 +23,11 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
+#include <stddef.h>
 #include "glpmat.h"
-#include "glpset.h"
 
 /*----------------------------------------------------------------------
--- create_mat - create sparse matrix.
+-- create_mat() -- create sparse matrix.
 --
 -- *Synopsis*
 --
@@ -36,23 +36,33 @@
 --
 -- *Description*
 --
--- The create_mat routine creates a real sparse matrix with m rows and
--- n columns. The created matrix initially is null matrix.
+-- The routine create_mat() creates a real sparse matrix, which has m
+-- rows and n columns. Initially the created matrix is empty, i.e. has
+-- no elements.
+--
+-- It is allowed to specify m = 0 and/or n = 0.
 --
 -- *Returns*
 --
--- The create_mat returns a pointer to the created matrix. */
+-- The routine create_mat() returns a pointer to the created matrix. */
 
 MAT *create_mat(int m, int n)
 {     MAT *A;
-      if (!(m > 0 && n > 0))
-         fault("create_mat: invalid dimension");
+      int m_max = 100, n_max = 100, i, j;
+      if (!(m >= 0 && n >= 0))
+         fault("create_mat: m = %d, n = %d; invalid dimension", m, n);
       A = umalloc(sizeof(MAT));
+      A->pool = create_pool(sizeof(ELEM));
+      while (m_max < m) m_max += m_max, insist(m_max > 0);
+      while (n_max < n) n_max += n_max, insist(n_max > 0);
+      A->m_max = m_max;
+      A->n_max = n_max;
       A->m = m;
       A->n = n;
-      A->pool = create_pool(sizeof(ELEM));
-      A->row = ucalloc(1+m, sizeof(ELEM *));
-      A->col = ucalloc(1+n, sizeof(ELEM *));
+      A->row = ucalloc(1+m_max, sizeof(ELEM *));
+      A->col = ucalloc(1+n_max, sizeof(ELEM *));
+      for (i = 1; i <= m; i++) A->row[i] = NULL;
+      for (j = 1; j <= n; j++) A->col[j] = NULL;
       return A;
 }
 
