@@ -92,12 +92,15 @@ void gm_scaling(MAT *A, double R[], double S[], int ord, double eps,
       int itmax)
 {     int iter;
       double told, tnew;
-      print("gm_scaling: scaling...");
       told = DBL_MAX;
-      for (iter = 1; iter <= itmax; iter++)
+      for (iter = 1; ; iter++)
       {  tnew = ratio(A, R, S);
-         print("gm_scaling: max / min = %9.3e", tnew);
-         if (told - tnew < eps * told) break;
+         if (iter == 1)
+            print("gm_scaling: max / min = %9.3e", tnew);
+         if (told - tnew < eps * told || iter > itmax)
+         {  print("gm_scaling: max / min = %9.3e", tnew);
+            break;
+         }
          told = tnew;
          if (ord == 0)
          {  scale_rows(A, R, S);
