@@ -36,8 +36,8 @@
 --
 -- *Description*
 --
--- The set_str routine copies data from the plain character string from
--- to the segmented character string str.
+-- The set_str routine copies data from the plain character string to
+-- the segmented character string str.
 --
 -- *Returns*
 --
