@@ -27,7 +27,7 @@
 #define _GLPK_H
 
 #ifndef _GLPAPI_H
-typedef struct { int _dummy; } LPI;
+typedef struct { int dummy; } LPI;
 #endif
 
 #define GLP_UNDEF    0  /* solution is undefined */
@@ -327,6 +327,12 @@ struct bbm1
       /* relative tolerance which is used to check if current value of
          the objective function is not better than for the best integer
          feasible solution found */
+      int meth;
+      /* this parameter specifies what version of the simplex method
+         should be used by the solver to find an optimal basis of LP
+         relaxation:
+         0 - rsm1_driver()
+         1 - glp_simplex2() */
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
@@ -502,6 +508,40 @@ extern int glp_pivot_in(LPI *lp, int flag[], struct piv1 *parm);
 extern int glp_pivot_out(LPI *lp, int flag[], struct piv1 *parm);
 /* pull structural variables from the basis */
 
+struct spx2
+{     /* primal simplex method parameter block */
+      int scale;
+      /* this parameter controls the scaling option:
+         0 - do not scale the problem
+         1 - scale the problem
+         2 - scale the problem using scale factors specified in the
+             problem object */
+      int initb;
+      /* this parameter controls the initial basis option:
+         0 - use the standard basis, where all auxiliary variables are
+             basic and all structural variables are non-basic
+         1 - use an advanced initial basis
+         2 - use the basis specified in the problem object */
+      int round;
+      /* this parameter controls the final solution rounding option:
+         0 - keep all computed primal and dual values "as is"
+         1 - replace computed primal and dual values, which are close
+             to zero, by exact zeros (this is performed once after the
+             final solution has been obtained) */
+      double tol_bnd;
+      /* tolerance used to check if the solution is primal feasible */
+      double tol_dj;
+      /* tolerance used to check if the solution is dual feasible */
+      double tol_piv;
+      /* tolerance used to choose pivot element of the simplex table */
+};
+
+extern void glp_init_spx2(struct spx2 *parm);
+/* initialize parameter block by default values */
+
+extern int glp_simplex2(LPI *lp, struct spx2 *parm);
+/* solve LP problem using primal simplex method */
+
 #endif
 
 /* eof */
