@@ -30,16 +30,19 @@
 
 #define aat_numb              _glp_aat_numb
 #define aat_symb              _glp_aat_symb
+#define append_lines          _glp_append_lines
 #define check_mat             _glp_check_mat
 #define check_mplets          _glp_check_mplets
 #define check_per             _glp_check_per
 #define clear_line            _glp_clear_line
+#define clear_lines           _glp_clear_lines
 #define clear_mat             _glp_clear_mat
 #define copy_mat              _glp_copy_mat
 #define copy_per              _glp_copy_per
 #define count_nz              _glp_count_nz
 #define create_mat            _glp_create_mat
 #define create_per            _glp_create_per
+#define delete_lines          _glp_delete_lines
 #define delete_mat            _glp_delete_mat
 #define delete_per            _glp_delete_per
 #define eq_scaling            _glp_eq_scaling
@@ -80,18 +83,26 @@ typedef struct PER PER;
 
 struct MAT
 {     /* sparse matrix */
-      int m;
-      /* number of rows (> 0) */
-      int n;
-      /* number of columns (> 0) */
       POOL *pool;
-      /* memory pool holding matrix elements */
-      ELEM **row; /* ELEM *row[1+m]; */
+      /* memory pool for allocating matrix elements */
+      int m_max;
+      /* current dimension of array of row pointers; this dimension is
+         automatically increased when necessary */
+      int n_max;
+      /* current dimension of array of column pointers; this dimension
+         is automatically increased when necessary */
+      int m;
+      /* number of rows (>= 0) */
+      int n;
+      /* number of columns (>= 0) */
+      ELEM **row; /* ELEM *row[1+m_max]; */
       /* array of row pointers; row[0] is not used; row[i] points to
-         the linked list for ith row (1 <= i <= m) */
-      ELEM **col; /* ELEM *col[1+n]; */
-      /* array or column pointers; col[0] is not used; col[j] points to
-         the linked list for jth column (1 <= j <= n) */
+         the i-th row (i = 1, ..., m); row[m+1], ..., row[m_max] are
+         reserved for new rows that can be added to the matrix */
+      ELEM **col; /* ELEM *col[1+n_max]; */
+      /* array of column pointers; col[0] is not used; col[i] points to
+         the j-th column (j = 1, ..., n); col[n+1], ..., col[n_max] are
+         reserved for new columns that can be added to the matrix */
 };
 
 struct ELEM
@@ -128,6 +139,9 @@ extern MAT *aat_numb(MAT *S, MAT *A, double D[], double work[]);
 extern MAT *aat_symb(MAT *S, MAT *A, char work[]);
 /* compute matrix product S = A * A'; symbolic phase */
 
+extern MAT *append_lines(MAT *A, int dm, int dn);
+/* append new rows and columns to sparse matrix */
+
 extern void check_mat(MAT *A);
 /* check sparse matrix for correctness */
 
@@ -140,6 +154,9 @@ extern void check_per(PER *P);
 extern MAT *clear_line(MAT *A, int k);
 /* clear row or column of sparse matrix */
 
+extern MAT *clear_lines(MAT *A, int rs[], int cs[]);
+/* clear rows and columns of sparse matrix */
+
 extern MAT *clear_mat(MAT *A);
 /* clear sparse matrix (A := 0) */
 
@@ -158,6 +175,9 @@ extern MAT *create_mat(int m, int n);
 extern PER *create_per(int n);
 /* create permutation matrix */
 
+extern MAT *delete_lines(MAT *A, int rs[], int cs[]);
+/* delete rows and columns from sparse matrix */
+
 extern void delete_mat(MAT *A);
 /* delete sparse matrix */
 
