@@ -36,7 +36,7 @@
 -- based on the revised simplex method is used.
 ----------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.3";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 3.0.4";
 
 static char *in_fname = NULL;
 /* name of the input text file */
@@ -68,7 +68,8 @@ static int option = 2;
 
 static int method = 'S';
 /* the method which should be used for solving a problem:
-   'S' - simplex method
+   'O' - simplex method, old version (based on rsm1_driver)
+   'S' - simplex method, new version (based on glp_simplex2)
    'I' - interior point method */
 
 static char *out_fname = NULL;
@@ -147,8 +148,9 @@ static void display_help(char *my_name)
       print("   --ini             find initial solution only");
       print("   --any             find any feasible solution");
       print("   --fin             find final solution (default)");
-      print("   --simplex         use revised simplex method (default)")
-         ;
+      print("   --old-sim         use simplex method, old version");
+      print("   --simplex         use simplex method, new version (defa"
+         "ult)");
       print("   --interior        use interior point method (for pure L"
          "P only)");
       print("   -o filename, --output filename");
@@ -160,7 +162,7 @@ static void display_help(char *my_name)
          "t");
       print("   -v, --version     display program version and exit");
       print("");
-      print("Options specific to simplex method:");
+      print("Options specific to simplex method (--old-sim assumed):");
       print("   --textbook        use options --noscale, --pfi, --prima"
          "l, --nosteep,");
       print("                     --norelax, --first, and --lifo by def"
@@ -259,6 +261,8 @@ static void process_cmdline(int argc, char *argv[])
             option = 1;
          else if (p("--fin"))
             option = 2;
+         else if (p("--old-sim"))
+            method = 'O';
          else if (p("--simplex"))
             method = 'S';
          else if (p("--interior"))
@@ -382,17 +386,26 @@ int main(int argc, char *argv[])
       /* solve LP/MIP problem */
       t_start = clock();
       switch (method)
-      {  case 'S':
+      {  case 'O':
+         case 'S':
             if (nomip || glp_get_num_int(lp) == 0)
-            {  struct rsm1 parm;
-               glp_init_rsm1(&parm);
-               parm.what = option;
-               parm.form = form;
-               parm.scale = scale;
-               parm.dual = use_dual;
-               parm.steep = steep;
-               parm.relax = relax;
-               glp_call_rsm1(lp, &parm);
+            {  if (method == 'O')
+               {  struct rsm1 parm;
+                  glp_init_rsm1(&parm);
+                  parm.what = option;
+                  parm.form = form;
+                  parm.scale = scale;
+                  parm.dual = use_dual;
+                  parm.steep = steep;
+                  parm.relax = relax;
+                  glp_call_rsm1(lp, &parm);
+               }
+               else
+               {  struct spx2 parm;
+                  glp_init_spx2(&parm);
+                  parm.scale = scale;
+                  glp_simplex2(lp, &parm);
+               }
             }
             else
             {  struct bbm1 parm;
@@ -400,6 +413,7 @@ int main(int argc, char *argv[])
                parm.what = option;
                parm.branch = branch;
                parm.btrack = btrack;
+               parm.meth = (method == 'O' ? 0 : 1);
                parm.form = form;
                parm.scale = scale;
                parm.dual = use_dual;
@@ -435,7 +449,7 @@ int main(int argc, char *argv[])
       print("Time used: %.1f secs",
          (double)(clock() - t_start) / (double)CLOCKS_PER_SEC);
       print("Memory used: %.1fM (%d bytes)",
-         (double)mem_tpeak / (1024.0 * 1024.0), mem_tpeak);
+         (double)mem_tpeak / (double)1000000, mem_tpeak);
       /* write problem solution found by the solver */
       if (out_fname != NULL && glp_print_soln(lp, out_fname) != 0)
       {  error("Unable to write problem solution");
